/* main-unix.c */

#ifdef __cplusplus
extern "C" {
#endif

int	main( int argc, char **argv );
void	chk_arg( int argc, char **argv );
bool_t	chk_opt_flg( const char *optarg );
void	overwrite_arg( void );
void	usage( FILE *fp );
void	child_ps_unix( void );
void	init_term_unix( void );
bool_t	chk_term_unix( void );
void	ena_term_unix( void );
void	dis_term_unix( void );
void	set_key_wait_unix( void );
void	clr_key_wait_unix( void );
void	set_key_wait_vtime( long wait_vtime );

#ifdef __cplusplus
}
#endif
